[evolvis-commits] r13851: Add test for building HTML from docbook

mirabilos at evolvis.org mirabilos at evolvis.org
Mon Feb 28 03:22:41 CET 2011


Author: mirabilos
Date: 2011-02-28 03:22:36 +0100 (Mon, 28 Feb 2011)
New Revision: 13851

Added:
   trunk/gforge_base/evolvisforge-5.1/tests/build/documentation/
   trunk/gforge_base/evolvisforge-5.1/tests/build/documentation/AllTests.php
   trunk/gforge_base/evolvisforge-5.1/tests/build/documentation/DocumentationTests.php
Modified:
   trunk/gforge_base/evolvisforge-5.1/tests/AllFullTests.php
Log:
Add test for building HTML from docbook

Modified: trunk/gforge_base/evolvisforge-5.1/tests/AllFullTests.php
===================================================================
--- trunk/gforge_base/evolvisforge-5.1/tests/build/documentation/AllTests.php	                        (rev 0)
+++ trunk/gforge_base/evolvisforge-5.1/tests/build/documentation/AllTests.php	2011-02-28 02:22:36 UTC (rev 13851)
@@ -0,0 +1,17 @@
+<?php
+require_once 'PHPUnit/Framework.php';
+ 
+require_once dirname(__FILE__).'/DocumentationTests.php';
+
+class Documentation_AllTests
+{
+    public static function suite()
+    {
+        $suite = new PHPUnit_Framework_TestSuite('PHPUnit Framework');
+ 
+        $suite->addTestSuite('Documentation_Tests');
+ 
+        return $suite;
+    }
+}
+?>

Added: trunk/gforge_base/evolvisforge-5.1/tests/build/documentation/DocumentationTests.php
===================================================================
--- trunk/gforge_base/evolvisforge-5.1/tests/build/documentation/DocumentationTests.php	                        (rev 0)
+++ trunk/gforge_base/evolvisforge-5.1/tests/build/documentation/DocumentationTests.php	2011-02-28 02:22:36 UTC (rev 13851)
@@ -0,0 +1,36 @@
+<?php
+
+require_once 'PHPUnit/Framework/TestCase.php';
+
+/**
+ * Documentation tests (html, pdf).
+ *
+ * @package   DocumentationTests
+ * @author    Alain Peyrat <aljeux at free.fr>
+ * @copyright 2009 Alain Peyrat. All rights reserved.
+ * @license   http://www.opensource.org/licenses/gpl-license.php  GPL License
+ */
+class Documentation_Tests extends PHPUnit_Framework_TestCase
+{
+    /**
+     * Build HTML documentation from docbook
+     */
+    public function testBuildHTMLDocumentation()
+    {
+	    $tests = dirname( dirname( dirname( dirname (__FILE__)))); 
+	    $base = dirname( $tests );
+	    system("cd ../gforge/docs/docbook; make TARGET=$base/build/documentation/ html", $retval);
+	    $this->assertEquals(0, $retval);
+    }
+
+    /**
+     * Build PDF documentation from docbook
+     */
+    public function skiptestBuildPDFDocumentation()
+    {
+	    $tests = dirname( dirname( dirname( dirname (__FILE__)))); 
+	    $base = dirname( $tests );
+	    system("cd ../gforge/docs/docbook; make TARGET=$base/build/documentation/ pdf", $retval);
+	    $this->assertEquals(0, $retval);
+    }
+}



More information about the evolvis-commits mailing list
--- trunk/gforge_base/evolvisforge-5.1/tests/AllFullTests.php	2011-02-28 02:22:26 UTC (rev 13850)
+++ trunk/gforge_base/evolvisforge-5.1/tests/AllFullTests.php	2011-02-28 02:22:36 UTC (rev 13851)
@@ -15,6 +15,7 @@
 
 // Build tests
 require_once 'build/packages/AllTests.php';
+require_once 'build/documentation/AllTests.php';
 
 // Remote tests
 //require_once 'remote/tarball/AllTests.php';
@@ -49,8 +50,9 @@
 		// Code tests
 		$suite->addTest(Syntax_AllTests::suite());
 
 		// Building packages tests
 		$suite->addTest(Packages_AllTests::suite());
+		$suite->addTest(Documentation_AllTests::suite());
 		
 		// Remote tests
 //		$suite->addTest(Remote_AllTests::suite());
@@ -49,8 +50,9 @@
 		$suite->addTest(Syntax_AllTests::suite());
 
-		// Building packages tests
+		// Building packages and documentation tests
 		$suite->addTest(Packages_AllTests::suite());

Added: trunk/gforge_base/evolvisforge-5.1/tests/build/documentation/AllTests.php
===================================================================